pitchtools.NumberedPitchClass
=============================

.. abjad-lineage:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass

.. autoclass:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.accidental
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.accidental_spelling
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.alteration_in_semitones
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.apply_accidental
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.diatonic_pitch_class_name
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.diatonic_pitch_class_number
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.invert
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.is_diatonic_pitch_class_name
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.is_diatonic_pitch_class_number
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.is_pitch_class_name
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.is_pitch_class_number
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.multiply
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.named_pitch_class
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.numbered_pitch_class
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.pitch_class_label
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.pitch_class_name
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.pitch_class_number
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.transpose
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.__abs__
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.__add__
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.__copy__
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.__eq__
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.__float__
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.__hash__
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.__int__
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.__ne__
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.__neg__
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.__repr__
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.__str__
      ~abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.__sub__

Bases
-----

- :py:class:`pitchtools.PitchClass <abjad.tools.pitchtools.PitchClass.PitchClass.PitchClass>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.accidental
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.accidental_spelling
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.alteration_in_semitones
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.diatonic_pitch_class_name
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.diatonic_pitch_class_number
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.named_pitch_class
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.numbered_pitch_class
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.pitch_class_label
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.pitch_class_name
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.pitch_class_number
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.apply_accidental
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.invert
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.multiply
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.transpose
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.is_diatonic_pitch_class_name
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.is_diatonic_pitch_class_number
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.is_pitch_class_name
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.is_pitch_class_number
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.__abs__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.__add__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.__copy__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.__float__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.__int__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.__neg__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.__str__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedPitchClass.NumberedPitchClass.NumberedPitchClass.__sub__
   :noindex:
